@@ -7,4 +7,4 @@ def test():
 	scenario = sp.test_scenario()
 	c1 = contract.SampleContract(0, sp.address('tz1a9GCc4UU6d5Z9spyozgKTARngb8DZKbNe'))
 	scenario += c1
-	scenario += c1.increment(1)
\ No newline at end of file
+	scenario += c1.increment(1).run(sender=sp.address('tz1a9GCc4UU6d5Z9spyozgKTARngb8DZKbNe'))
\ No newline at end of file
